@@ -1,6 +1,6 @@
 /*
  *  cryptmount - a utility for user-level mounting of encrypted filesystems
- *  (C)Copyright 2005-2015, RW Penney
+ *  (C)Copyright 2005-2016, RW Penney
  */
 
 /*
@@ -140,7 +140,7 @@ usage: cryptmount [OPTION [target ...]]\n\
     --swapoff <target>\n\
     --version\n\
 \n\
-  please report bugs to <cryptmount@rwpenney.org.uk>\n\
+  please report bugs to <cryptmount@rwpenney.uk>\n\
 ");
 
 
@@ -1561,5 +1561,5 @@ int main(int argc, char *argv[])
 }
 
 /*
- *  (C)Copyright 2005-2015, RW Penney
+ *  (C)Copyright 2005-2016, RW Penney
  */
